#
# For managers
#

resource "aws_iam_role" "swarm_manager" {
  name        = "DockerSwarmEC2ManagerRole"
  description = "EC2 role for Docker Swarm managers."

  assume_role_policy = <<EOF
{
  "Version": "2012-10-17",
  "Statement": [
    {
      "Effect": "Allow",
      "Principal": {
        "Service": "ec2.amazonaws.com"
      },
      "Action": "sts:AssumeRole"
    }
  ]
}
EOF

}

resource "aws_iam_role_policy_attachment" "swarm_manager_ecr-ro" {
  role       = aws_iam_role.swarm_manager.name
  policy_arn = "arn:aws:iam::aws:policy/AmazonEC2ContainerRegistryReadOnly"
}

resource "aws_iam_role_policy_attachment" "swarm_manager_ssm-rw" {
  role       = aws_iam_role.swarm_manager.name
  policy_arn = "arn:aws:iam::aws:policy/AmazonSSMFullAccess"
}

resource "aws_iam_role_policy_attachment" "swarm_manager_efs-rw" {
  role       = aws_iam_role.swarm_manager.name
  policy_arn = "arn:aws:iam::aws:policy/AmazonElasticFileSystemFullAccess"
}

resource "aws_iam_role_policy_attachment" "swarm_manager_cloudstor-rw" {
  role       = aws_iam_role.swarm_manager.name
  policy_arn = aws_iam_policy.cloudstor_ebs_policy.arn
}

resource "aws_iam_instance_profile" "swarm_manager" {
  role = aws_iam_role.swarm_manager.name
  name = "DockerSwarmEC2ManagerRole"
}

#
# For workers
#

resource "aws_iam_role" "swarm_worker" {
  name        = "DockerSwarmEC2WorkerRole"
  description = "EC2 role for Docker Swarm workers."

  assume_role_policy = <<EOF
{
  "Version": "2012-10-17",
  "Statement": [
    {
      "Effect": "Allow",
      "Principal": {
        "Service": "ec2.amazonaws.com"
      },
      "Action": "sts:AssumeRole"
    }
  ]
}
EOF

}

resource "aws_iam_role_policy_attachment" "swarm_worker_ecr-ro" {
  role       = aws_iam_role.swarm_worker.name
  policy_arn = "arn:aws:iam::aws:policy/AmazonEC2ContainerRegistryReadOnly"
}

resource "aws_iam_role_policy_attachment" "swarm_worker_ssm-rw" {
  role       = aws_iam_role.swarm_worker.name
  policy_arn = "arn:aws:iam::aws:policy/AmazonSSMFullAccess"
}

resource "aws_iam_role_policy_attachment" "swarm_worker_efs-rw" {
  role       = aws_iam_role.swarm_worker.name
  policy_arn = "arn:aws:iam::aws:policy/AmazonElasticFileSystemFullAccess"
}

resource "aws_iam_role_policy_attachment" "swarm_worker_cloudstor-rw" {
  role       = aws_iam_role.swarm_worker.name
  policy_arn = aws_iam_policy.cloudstor_ebs_policy.arn
}

resource "aws_iam_instance_profile" "swarm_worker" {
  role = aws_iam_role.swarm_worker.name
  name = "DockerSwarmEC2WorkerRole"
}

#
# Docker Cloudstor volume driver (EBS-part)
#

resource "aws_iam_policy" "cloudstor_ebs_policy" {
  name        = "AmazonCloudstorEBSAccess"
  path        = "/"
  description = "Provides access to EBS part of Docker Cloudstor volume driver."

  policy = <<EOF
{
  "Version": "2012-10-17",
  "Statement": [
    {
      "Action": [
          "ec2:CreateTags",
          "ec2:AttachVolume",
          "ec2:DetachVolume",
          "ec2:CreateVolume",
          "ec2:DeleteVolume",
          "ec2:DescribeVolumes",
          "ec2:DescribeVolumeStatus",
          "ec2:CreateSnapshot",
          "ec2:DeleteSnapshot",
          "ec2:DescribeSnapshots"
      ],
      "Effect": "Allow",
      "Resource": "*"
    }
  ]
}
EOF
}
