resource "aws_instance" "leader" {
  count                       = 1
  ami                         = module.amzn2_docker_ami.ami_id
  instance_type               = var.leader_instance_type
  associate_public_ip_address = true

  subnet_id  = element(var.jz_vpc.subnets.*.id, count.index % 3)
  private_ip = cidrhost(cidrsubnet(element(var.jz_vpc.subnets.*.cidr_block, count.index), 4, 2), count.index + 10)

  key_name             = var.jz_swarm_generic.ssh_key_pair.key_name
  iam_instance_profile = var.jz_swarm_global.iam_profiles.swarm_manager.name

  vpc_security_group_ids = flatten([
    var.jz_swarm_generic.security_groups.*.id,
    var.app_security_groups.*.id,
    aws_security_group.app.id,
    aws_security_group.dev.id,
  ])

  root_block_device {
    volume_size = var.ebs_size
  }

  tags = {
    Name = "${var.name}-${var.env}-leader"
    Env  = var.env
  }

  lifecycle {
    #prevent_destroy = true
    ignore_changes = [
      ami,
      root_block_device,
      instance_type,
      ebs_optimized,
      tags,
    ]
  }
}

resource "aws_ssm_parameter" "leader-ip" {
  type  = "String"
  name  = "docker-${var.name}-${var.env}-leader"
  value = aws_instance.leader[0].private_ip

  tags = {
    Env  = var.env
  }
}
