variable "name" {
  type        = string
  description = "The name of the Swarm project."
}

variable "env" {
  type        = string
  description = "Deployment environment."
}

variable "managers_count" {
  type        = number
  default     = 3
  description = "Docker Swarm managers count, including leader."
}

variable "workers_count" {
  type        = number
  default     = 1
  description = "Docker Swarm workers count."
}

variable "leader_instance_type" {
  type        = string
  default     = "t3.small"
  description = "AWS instance type to run leader in Swarm node."
}

variable "manager_instance_type" {
  type        = string
  default     = "t3.nano"
  description = "AWS instance type to run leader in Swarm node."
}

variable "worker_instance_type" {
  type        = string
  default     = "t3.medium"
  description = "AWS instance type to run leader in Swarm node."
}

variable "ebs_size" {
  type        = number
  default     = 64
  description = "Size of EBS volume to be reserved for Swarm node. [GB]"
}

variable "jz_vpc" {
  type        = object({
    self    = object({
      id = string
    })
    subnets = list(any)
  })
  description = "A reference to jz_vpc module."
}

variable "jz_swarm_global" {
  type        = object({
    iam_profiles = object({
      swarm_manager = object({
        name = string
      })
      swarm_worker  = object({
        name = string
      })
    })
  })
  description = "A reference to jz_swarm_global module."
}

variable "jz_swarm_generic" {
  type        = object({
    kms_key            = object({
      id = string
    })
    ssh_key_pair       = object({
      key_name           = string
      public_key_path    = string
      private_key_path   = string
      public_key_openssh = string
      private_key_pem    = string
    })
    swarm_mgmt_cidrs   = list(string)
    security_groups    = list(any)
    vpc_security_group = object({
      id = string
    })
  })
  description = "A reference to jz_swarm_generic module."
}

variable "app_security_groups" {
  type        = list
  default     = []
  description = "App-specific security groups to be used. Optional."
}

variable "app_ports" {
  type        = list
  default     = []
  description = "A list of ports serving the application."
}

variable "dev_ports" {
  type        = list
  default     = []
  description = "A list of ports serving development tools."
}
